#!/bin/bash

set -e

logs="$(ls ghc-7.10-no-call-arity-no-oneshot-plain-foldl-2015*slow-cachegrind.log|tail -n 1) \
      $(ls ghc-7.10-plain-foldl-2015*slow-cachegrind.log|tail -n 1) \
      $(ls ghc-7.10-2015*slow-cachegrind.log|tail -n 1) \
      $(ls ghc-7.10-no-call-arity-no-oneshot-2015*slow-cachegrind.log|tail -n 1)"

pruned=""
for log in $logs;
do
  sed '/==nofib== cacheprof/,/Finished making all in cacheprof/d' $log > $log-pruned
  pruned="$pruned $log-pruned"
done

nofib-analyse --columns=Allocs,Instrs -l -i 0.1  $pruned | ./fixup.pl $logs > call-arity-nofib-table.tex
nofib-analyse --columns=Allocs -l -i 0.1  $pruned | ./fixup.pl $logs > call-arity-nofib-table-alloc.tex
nofib-analyse --columns=Instrs -l -i 0.1  $pruned | ./fixup.pl $logs > call-arity-nofib-table-instrs.tex
nofib-analyse --columns="Comp. Alloc,Comp. Time" -l -i 0.1  $pruned | ./summary-only.pl $logs | grep 'Geometric' | sed -e 's/Geometric Mean/nofib/'> call-arity-nofib-comp-table.tex

for log in $logs;
do
  rm -f $log-pruned
done

logs2="$(ls ghc-7.10-no-call-arity-no-oneshot-2015*slow-cachegrind.log|tail -n 1) \
       $(ls ghc-7.10-no-call-arity-2015*slow-cachegrind.log|tail -n 1) \
       $(ls ghc-7.10-no-oneshot-2015*slow-cachegrind.log|tail -n 1) \
       $(ls ghc-7.10-2015*slow-cachegrind.log|tail -n 1)"

pruned=""
for log in $logs2;
do
  sed '/==nofib== cacheprof/,/Finished making all in cacheprof/d' $log > $log-pruned
  pruned="$pruned $log-pruned"
done

nofib-analyse --columns=Allocs,Instrs -l -i 0.1  $logs2 | ./fixup.pl $logs2 > oneshot-table.tex

for log in $logs2;
do
  rm -f $log-pruned
done

buildlogs="$(ls buildlog-ghc-7.10-no-call-arity-no-oneshot-plain-foldl-2015*|tail -n 1) \
      $(ls buildlog-ghc-7.10-plain-foldl-2015*|tail -n 1) \
      $(ls buildlog-ghc-7.10-2015*|tail -n 1) \
      $(ls buildlog-ghc-7.10-no-call-arity-no-oneshot-2015*|tail -n 1)"
./buildlog.pl $buildlogs > call-arity-ghc-comp-table.tex
